@@ -643,6 +643,7 @@ __thread bool mysql_thread___default_reconnect;
 __thread bool mysql_thread___session_idle_show_processlist;
 __thread bool mysql_thread___sessions_sort;
 __thread bool mysql_thread___session_idle_ms;
+__thread bool mysql_thread___kill_backend_connection_when_disconnect;
 
 /* variables used for Query Cache */
 __thread int mysql_thread___query_cache_size_MB;
@@ -750,6 +751,7 @@ extern __thread bool mysql_thread___default_reconnect;
 extern __thread bool mysql_thread___session_idle_show_processlist;
 extern __thread bool mysql_thread___sessions_sort;
 extern __thread bool mysql_thread___session_idle_ms;
+extern __thread bool mysql_thread___kill_backend_connection_when_disconnect;
 
 /* variables used for Query Cache */
 extern __thread int mysql_thread___query_cache_size_MB;
