@@ -610,7 +610,7 @@ void * monitor_read_only_thread(void *arg) {
 	}
 
 	mmsd->t1=monotonic_time();
-	mmsd->async_exit_status=mysql_query_start(&mmsd->interr,mmsd->mysql,"SHOW GLOBAL VARIABLES LIKE 'read_only'");
+	mmsd->async_exit_status=mysql_query_start(&mmsd->interr,mmsd->mysql,"SELECT @@global.read_only");
 	while (mmsd->async_exit_status) {
 		mmsd->async_exit_status=wait_for_mysql(mmsd->mysql, mmsd->async_exit_status);
 		unsigned long long now=monotonic_time();
@@ -674,7 +674,7 @@ __exit_monitor_read_only_thread:
 			fields = mysql_fetch_fields(mmsd->result);
 			for(k = 0; k < num_fields; k++) {
 				//if (strcmp("VARIABLE_NAME", fields[k].name)==0) {
-				if (strcmp((char *)"Value", (char *)fields[k].name)==0) {
+				if (strcmp((char *)"@@global.read_only", (char *)fields[k].name)==0) {
 					j=k;
 				}
 			}
@@ -1199,7 +1199,7 @@ void * MySQL_Monitor::monitor_connect() {
 		int affected_rows=0;
 		SQLite3_result *resultset=NULL;
 		// add support for SSL
-		char *query=(char *)"SELECT hostname, port, MAX(use_ssl) use_ssl FROM mysql_servers GROUP BY hostname, port";
+		char *query=(char *)"SELECT hostname, port, MAX(use_ssl) use_ssl FROM mysql_servers GROUP BY hostname, port ORDER BY RANDOM()";
 		unsigned int glover;
 		t1=monotonic_time();
 
@@ -1228,6 +1228,15 @@ void * MySQL_Monitor::monitor_connect() {
 			int us=100;
 			if (resultset->rows_count) {
 				us=mysql_thread___monitor_connect_interval/2/resultset->rows_count;
+				us*=40;
+				if (us > 1000000) {
+					us = 10000;
+				}
+				us = us + rand()%us;
+				if (resultset->rows_count==1) {
+					// only 1 server, sleep also before creating the job
+					usleep(us);
+				}
 			}
 			for (std::vector<SQLite3_row *>::iterator it = resultset->rows.begin() ; it != resultset->rows.end(); ++it) {
 				SQLite3_row *r=*it;
@@ -1313,7 +1322,7 @@ void * MySQL_Monitor::monitor_ping() {
 		int cols=0;
 		int affected_rows=0;
 		SQLite3_result *resultset=NULL;
-		char *query=(char *)"SELECT hostname, port, MAX(use_ssl) use_ssl FROM mysql_servers WHERE status NOT LIKE 'OFFLINE\%' GROUP BY hostname, port";
+		char *query=(char *)"SELECT hostname, port, MAX(use_ssl) use_ssl FROM mysql_servers WHERE status NOT LIKE 'OFFLINE\%' GROUP BY hostname, port ORDER BY RANDOM()";
 		t1=monotonic_time();
 
 		if (!GloMTH) return NULL;	// quick exit during shutdown/restart
@@ -1341,6 +1350,15 @@ void * MySQL_Monitor::monitor_ping() {
 			int us=100;
 			if (resultset->rows_count) {
 				us=mysql_thread___monitor_ping_interval/2/resultset->rows_count;
+				us*=40;
+				if (us > 1000000) {
+					us = 10000;
+				}
+				us = us + rand()%us;
+				if (resultset->rows_count==1) {
+					// only 1 server, sleep also before creating the job
+					usleep(us);
+				}
 			}
 			for (std::vector<SQLite3_row *>::iterator it = resultset->rows.begin() ; it != resultset->rows.end(); ++it) {
 				SQLite3_row *r=*it;
@@ -1567,7 +1585,7 @@ void * MySQL_Monitor::monitor_read_only() {
 		char *error=NULL;
 		SQLite3_result *resultset=NULL;
 		// add support for SSL
-		char *query=(char *)"SELECT hostname, port, MAX(use_ssl) use_ssl FROM mysql_servers JOIN mysql_replication_hostgroups ON hostgroup_id=writer_hostgroup OR hostgroup_id=reader_hostgroup WHERE status NOT LIKE 'OFFLINE\%' GROUP BY hostname, port";
+		char *query=(char *)"SELECT hostname, port, MAX(use_ssl) use_ssl FROM mysql_servers JOIN mysql_replication_hostgroups ON hostgroup_id=writer_hostgroup OR hostgroup_id=reader_hostgroup WHERE status NOT LIKE 'OFFLINE\%' GROUP BY hostname, port ORDER BY RANDOM()";
 		t1=monotonic_time();
 
 		if (!GloMTH) return NULL;	// quick exit during shutdown/restart
@@ -1595,6 +1613,15 @@ void * MySQL_Monitor::monitor_read_only() {
 			int us=100;
 			if (resultset->rows_count) {
 				us=mysql_thread___monitor_read_only_interval/2/resultset->rows_count;
+				us*=40;
+				if (us > 1000000) {
+					us = 10000;
+				}
+				us = us + rand()%us;
+				if (resultset->rows_count==1) {
+					// only 1 server, sleep also before creating the job
+					usleep(us);
+				}
 			}
 			for (std::vector<SQLite3_row *>::iterator it = resultset->rows.begin() ; it != resultset->rows.end(); ++it) {
 				SQLite3_row *r=*it;
@@ -1839,7 +1866,7 @@ void * MySQL_Monitor::monitor_replication_lag() {
 			for (std::vector<SQLite3_row *>::iterator it = resultset->rows.begin() ; it != resultset->rows.end(); ++it) {
 				SQLite3_row *r=*it;
 				bool rc_ping = true;
-				rc_ping = server_responds_to_ping(r->fields[0],atoi(r->fields[1]));
+				rc_ping = server_responds_to_ping(r->fields[1],atoi(r->fields[2]));
 				if (rc_ping) { // only if server is responding to pings
 					MySQL_Monitor_State_Data *mmsd = new MySQL_Monitor_State_Data(r->fields[1], atoi(r->fields[2]), NULL, atoi(r->fields[4]), atoi(r->fields[0]));
 					mmsd->mondb=monitordb;
